pub struct State {
pub len: usize,
pub link: Option<usize>,
pub next: BTreeMap<char, usize>,
}Expand description
State of a suffix automaton.
Fields
len: usizeLength of the longest substring represented by this state.
link: Option<usize>Suffix link: points to the state representing the longest proper suffix of this state’s substrings.
next: BTreeMap<char, usize>Transitions keyed by character.